@@ -60,6 +60,11 @@ class SpectroscopyPanel(QtWidgets.QWidget, CustomWidget):
             self.control.write_data()
         self.ids.filter_automatic.stateChanged.connect(automatic_changed)
 
+        def invert_changed(value):
+            self.get_param('invert').value = bool(value)
+            self.control.write_data()
+        self.ids.invert.stateChanged.connect(invert_changed)
+
     def connection_established(self):
         params = self.app().parameters
         self.control = self.app().control
@@ -79,7 +84,12 @@ class SpectroscopyPanel(QtWidgets.QWidget, CustomWidget):
         )
         param2ui(
             self.get_param('offset'),
-            self.ids.signal_offset
+            self.ids.signal_offset,
+            lambda v: v / 8191.0
+        )
+        param2ui(
+            self.get_param('invert'),
+            self.ids.invert
         )
         param2ui(
             self.get_param('filter_automatic'),
